translate.storage.properties.DialectStrings

Package translate :: Package storage :: Module properties :: Class DialectStrings |
[hide private]
[frames] | no frames]

# Class DialectStrings

source code

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Methods | [hide private]
key_strip(cls, key) Strip uneeded characters from the key | source code
value_strip(cls, value) Strip uneeded characters from the value | source code
encode(cls, string, encoding=None) Encode the string | source code
Inherited from `Dialect`: `find_delimiter`

Class Variables | [hide private]
| name = `"strings"` hash(x)
| default_encoding = `"utf-16"`
| delimiters = `[u"="]` hash(x)
| pair_terminator = `u";"`
| key_wrap_char = `u'"'`
| value_wrap_char = `u'"'`
| drop_comments = `["/* No comment provided by engineer. */"]`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### key_strip(cls, key) Class Method | source code
Strip uneeded characters from the key Overrides: Dialect.key_strip

### value_strip(cls, value) Class Method | source code
Strip uneeded characters from the value Overrides: Dialect.value_strip

### encode(cls, string, encoding=None) Class Method | source code
Encode the string Overrides: Dialect.encode (inherited documentation)